| Copyright | (c) 2016 Maarten Faddegon |
|---|---|
| License | BSD3 |
| Maintainer | hoed@maartenfaddegon.nl |
| Stability | experimental |
| Portability | POSIX |
| Safe Haskell | None |
| Language | Haskell2010 |
Debug.NoHoed
Description
Hoed is a tracer and debugger for the programming language Haskell.
This is a drop-in replacement of the Debug.Hoed.Pure or Debug.Hoed.Stk modules and disables tracing (all functions are variations of id).
Read more about Hoed on its project homepage https://wiki.haskell.org/Hoed.
Papers on the theory behind Hoed can be obtained via http://maartenfaddegon.nl/#pub.
I am keen to hear about your experience with Hoed: where did you find it useful and where would you like to see improvement? You can send me an e-mail at hoed@maartenfaddegon.nl, or use the github issue tracker https://github.com/MaartenFaddegon/hoed/issues.
- observe :: String -> a -> a
- runO :: IO a -> IO ()
- printO :: Show a => a -> IO ()
- testO :: Show a => (a -> Bool) -> a -> IO ()
- observeBase :: a -> Parent -> a
- class Observable a where
- data Parent = Parent
- class Generic a where
- send :: String -> ObserverM a -> Parent -> a
- newtype ObserverM a = ObserverM {}
- (<<) :: Observable a => ObserverM (a -> b) -> a -> ObserverM b
Documentation
observeBase :: a -> Parent -> a Source #
class Observable a where Source #
Methods
observer :: a -> Parent -> a Source #
observer :: Generic a => a -> Parent -> a Source #
Instances
Representable types of kind *. This class is derivable in GHC with the DeriveGeneric flag on.
Methods
Convert from the datatype to its representation
Convert from the representation to the datatype
Instances